==> cdpkits-1.2.5-py3-none-any.whl: cdpkit/protocol/Page/__init__.py <==
from .events import (
    BackForwardCacheNotUsed,
    CompilationCacheProduced,
    DocumentOpened,
    DomContentEventFired,
    DownloadProgress,
    DownloadWillBegin,
    FileChooserOpened,
    FrameAttached,
    FrameClearedScheduledNavigation,
    FrameDetached,
    FrameNavigated,
    FrameRequestedNavigation,
    FrameResized,
    FrameScheduledNavigation,
    FrameStartedLoading,
    FrameStartedNavigating,
    FrameStoppedLoading,
    FrameSubtreeWillBeDetached,
    InterstitialHidden,
    InterstitialShown,
    JavascriptDialogClosed,
    JavascriptDialogOpening,
    LifecycleEvent,
    LoadEventFired,
    NavigatedWithinDocument,
    ScreencastFrame,
    ScreencastVisibilityChanged,
    WindowOpen,
)
from .methods import (
    AddCompilationCache,
    AddScriptToEvaluateOnLoad,
    AddScriptToEvaluateOnNewDocument,
    BringToFront,
    CaptureScreenshot,
    CaptureSnapshot,
    ClearCompilationCache,
    ClearDeviceMetricsOverride,
    ClearDeviceOrientationOverride,
    ClearGeolocationOverride,
    Close,
    Crash,
    CreateIsolatedWorld,
    DeleteCookie,
    Disable,
    Enable,
    GenerateTestReport,
    GetAdScriptAncestryIds,
    GetAppId,
    GetAppManifest,
    GetFrameTree,
    GetInstallabilityErrors,
    GetLayoutMetrics,
    GetManifestIcons,
    GetNavigationHistory,
    GetOriginTrials,
    GetPermissionsPolicyState,
    GetResourceContent,
    GetResourceTree,
    HandleJavaScriptDialog,
    Navigate,
    NavigateToHistoryEntry,
    PrintToPDF,
    ProduceCompilationCache,
    Reload,
    RemoveScriptToEvaluateOnLoad,
    RemoveScriptToEvaluateOnNewDocument,
    ResetNavigationHistory,
    ScreencastFrameAck,
    SearchInResource,
    SetAdBlockingEnabled,
    SetBypassCSP,
    SetDeviceMetricsOverride,
    SetDeviceOrientationOverride,
    SetDocumentContent,
    SetDownloadBehavior,
    SetFontFamilies,
    SetFontSizes,
    SetGeolocationOverride,
    SetInterceptFileChooserDialog,
    SetLifecycleEventsEnabled,
    SetPrerenderingAllowed,
    SetRPHRegistrationMode,
    SetSPCTransactionMode,
    SetTouchEmulationEnabled,
    SetWebLifecycleState,
    StartScreencast,
    StopLoading,
    StopScreencast,
    WaitForDebugger,
)
from .types import (
    AdFrameExplanation,
    AdFrameStatus,
    AdFrameType,
    AdScriptId,
    AppManifestError,
    AppManifestParsedProperties,
    AutoResponseMode,
    BackForwardCacheBlockingDetails,
    BackForwardCacheNotRestoredExplanation,
    BackForwardCacheNotRestoredExplanationTree,
    BackForwardCacheNotRestoredReason,
    BackForwardCacheNotRestoredReasonType,
    ClientNavigationDisposition,
    ClientNavigationReason,
    CompilationCacheParams,
    CrossOriginIsolatedContextType,
    DialogType,
    FileFilter,
    FileHandler,
    FontFamilies,
    FontSizes,
    Frame,
    FrameId,
    FrameResource,
    FrameResourceTree,
    FrameTree,
    GatedAPIFeatures,
    ImageResource,
    InstallabilityError,
    InstallabilityErrorArgument,
    LaunchHandler,
    LayoutViewport,
    NavigationEntry,
    NavigationType,
    OriginTrial,
    OriginTrialStatus,
    OriginTrialToken,
    OriginTrialTokenStatus,
    OriginTrialTokenWithStatus,
    OriginTrialUsageRestriction,
    PermissionsPolicyBlockLocator,
    PermissionsPolicyBlockReason,
    PermissionsPolicyFeature,
    PermissionsPolicyFeatureState,
    ProtocolHandler,
    ReferrerPolicy,
    RelatedApplication,
    ScopeExtension,
    ScreencastFrameMetadata,
    Screenshot,
    ScriptFontFamilies,
    ScriptIdentifier,
    SecureContextType,
    SecurityOriginDetails,
    ShareTarget,
    Shortcut,
    TransitionType,
    Viewport,
    VisualViewport,
    WebAppManifest,
)

__all__ = [
    FrameId,
    AdFrameType,
    AdFrameExplanation,
    AdFrameStatus,
    AdScriptId,
    SecureContextType,
    CrossOriginIsolatedContextType,
    GatedAPIFeatures,
    PermissionsPolicyFeature,
    PermissionsPolicyBlockReason,
    PermissionsPolicyBlockLocator,
    PermissionsPolicyFeatureState,
    OriginTrialTokenStatus,
    OriginTrialStatus,
    OriginTrialUsageRestriction,
    OriginTrialToken,
    OriginTrialTokenWithStatus,
    OriginTrial,
    SecurityOriginDetails,
    Frame,
    FrameResource,
    FrameResourceTree,
    FrameTree,
    ScriptIdentifier,
    TransitionType,
    NavigationEntry,
    ScreencastFrameMetadata,
    DialogType,
    AppManifestError,
    AppManifestParsedProperties,
    LayoutViewport,
    VisualViewport,
    Viewport,
    FontFamilies,
    ScriptFontFamilies,
    FontSizes,
    ClientNavigationReason,
    ClientNavigationDisposition,
    InstallabilityErrorArgument,
    InstallabilityError,
    ReferrerPolicy,
    CompilationCacheParams,
    FileFilter,
    FileHandler,
    ImageResource,
    LaunchHandler,
    ProtocolHandler,
    RelatedApplication,
    ScopeExtension,
    Screenshot,
    ShareTarget,
    Shortcut,
    WebAppManifest,
    AutoResponseMode,
    NavigationType,
    BackForwardCacheNotRestoredReason,
    BackForwardCacheNotRestoredReasonType,
    BackForwardCacheBlockingDetails,
    BackForwardCacheNotRestoredExplanation,
    BackForwardCacheNotRestoredExplanationTree,
    DomContentEventFired,
    FileChooserOpened,
    FrameAttached,
    FrameClearedScheduledNavigation,
    FrameDetached,
    FrameSubtreeWillBeDetached,
    FrameNavigated,
    DocumentOpened,
    FrameResized,
    FrameStartedNavigating,
    FrameRequestedNavigation,
    FrameScheduledNavigation,
    FrameStartedLoading,
    FrameStoppedLoading,
    DownloadWillBegin,
    DownloadProgress,
    InterstitialHidden,
    InterstitialShown,
    JavascriptDialogClosed,
    JavascriptDialogOpening,
    LifecycleEvent,
    BackForwardCacheNotUsed,
    LoadEventFired,
    NavigatedWithinDocument,
    ScreencastFrame,
    ScreencastVisibilityChanged,
    WindowOpen,
    CompilationCacheProduced,
    AddScriptToEvaluateOnLoad,
    AddScriptToEvaluateOnNewDocument,
    BringToFront,
    CaptureScreenshot,
    CaptureSnapshot,
    ClearDeviceMetricsOverride,
    ClearDeviceOrientationOverride,
    ClearGeolocationOverride,
    CreateIsolatedWorld,
    DeleteCookie,
    Disable,
    Enable,
    GetAppManifest,
    GetInstallabilityErrors,
    GetManifestIcons,
    GetAppId,
    GetAdScriptAncestryIds,
    GetFrameTree,
    GetLayoutMetrics,
    GetNavigationHistory,
    ResetNavigationHistory,
    GetResourceContent,
    GetResourceTree,
    HandleJavaScriptDialog,
    Navigate,
    NavigateToHistoryEntry,
    PrintToPDF,
    Reload,
    RemoveScriptToEvaluateOnLoad,
    RemoveScriptToEvaluateOnNewDocument,
    ScreencastFrameAck,
    SearchInResource,
    SetAdBlockingEnabled,
    SetBypassCSP,
    GetPermissionsPolicyState,
    GetOriginTrials,
    SetDeviceMetricsOverride,
    SetDeviceOrientationOverride,
    SetFontFamilies,
    SetFontSizes,
    SetDocumentContent,
    SetDownloadBehavior,
    SetGeolocationOverride,
    SetLifecycleEventsEnabled,
    SetTouchEmulationEnabled,
    StartScreencast,
    StopLoading,
    Crash,
    Close,
    SetWebLifecycleState,
    StopScreencast,
    ProduceCompilationCache,
    AddCompilationCache,
    ClearCompilationCache,
    SetSPCTransactionMode,
    SetRPHRegistrationMode,
    GenerateTestReport,
    WaitForDebugger,
    SetInterceptFileChooserDialog,
    SetPrerenderingAllowed,
]

==> cdpkits-1.2.7-py3-none-any.whl: cdpkit/protocol/Page/__init__.py <==
from .events import (
    BackForwardCacheNotUsed,
    CompilationCacheProduced,
    DocumentOpened,
    DomContentEventFired,
    DownloadProgress,
    DownloadWillBegin,
    FileChooserOpened,
    FrameAttached,
    FrameClearedScheduledNavigation,
    FrameDetached,
    FrameNavigated,
    FrameRequestedNavigation,
    FrameResized,
    FrameScheduledNavigation,
    FrameStartedLoading,
    FrameStartedNavigating,
    FrameStoppedLoading,
    FrameSubtreeWillBeDetached,
    InterstitialHidden,
    InterstitialShown,
    JavascriptDialogClosed,
    JavascriptDialogOpening,
    LifecycleEvent,
    LoadEventFired,
    NavigatedWithinDocument,
    ScreencastFrame,
    ScreencastVisibilityChanged,
    WindowOpen,
)
from .methods import (
    AddCompilationCache,
    AddScriptToEvaluateOnLoad,
    AddScriptToEvaluateOnNewDocument,
    BringToFront,
    CaptureScreenshot,
    CaptureSnapshot,
    ClearCompilationCache,
    ClearDeviceMetricsOverride,
    ClearDeviceOrientationOverride,
    ClearGeolocationOverride,
    Close,
    Crash,
    CreateIsolatedWorld,
    DeleteCookie,
    Disable,
    Enable,
    GenerateTestReport,
    GetAdScriptAncestry,
    GetAppId,
    GetAppManifest,
    GetFrameTree,
    GetInstallabilityErrors,
    GetLayoutMetrics,
    GetManifestIcons,
    GetNavigationHistory,
    GetOriginTrials,
    GetPermissionsPolicyState,
    GetResourceContent,
    GetResourceTree,
    HandleJavaScriptDialog,
    Navigate,
    NavigateToHistoryEntry,
    PrintToPDF,
    ProduceCompilationCache,
    Reload,
    RemoveScriptToEvaluateOnLoad,
    RemoveScriptToEvaluateOnNewDocument,
    ResetNavigationHistory,
    ScreencastFrameAck,
    SearchInResource,
    SetAdBlockingEnabled,
    SetBypassCSP,
    SetDeviceMetricsOverride,
    SetDeviceOrientationOverride,
    SetDocumentContent,
    SetDownloadBehavior,
    SetFontFamilies,
    SetFontSizes,
    SetGeolocationOverride,
    SetInterceptFileChooserDialog,
    SetLifecycleEventsEnabled,
    SetPrerenderingAllowed,
    SetRPHRegistrationMode,
    SetSPCTransactionMode,
    SetTouchEmulationEnabled,
    SetWebLifecycleState,
    StartScreencast,
    StopLoading,
    StopScreencast,
    WaitForDebugger,
)
from .types import (
    AdFrameExplanation,
    AdFrameStatus,
    AdFrameType,
    AdScriptAncestry,
    AdScriptId,
    AppManifestError,
    AppManifestParsedProperties,
    BackForwardCacheBlockingDetails,
    BackForwardCacheNotRestoredExplanation,
    BackForwardCacheNotRestoredExplanationTree,
    BackForwardCacheNotRestoredReason,
    BackForwardCacheNotRestoredReasonType,
    ClientNavigationDisposition,
    ClientNavigationReason,
    CompilationCacheParams,
    CrossOriginIsolatedContextType,
    DialogType,
    FileFilter,
    FileHandler,
    FontFamilies,
    FontSizes,
    Frame,
    FrameId,
    FrameResource,
    FrameResourceTree,
    FrameTree,
    GatedAPIFeatures,
    ImageResource,
    InstallabilityError,
    InstallabilityErrorArgument,
    LaunchHandler,
    LayoutViewport,
    NavigationEntry,
    NavigationType,
    OriginTrial,
    OriginTrialStatus,
    OriginTrialToken,
    OriginTrialTokenStatus,
    OriginTrialTokenWithStatus,
    OriginTrialUsageRestriction,
    PermissionsPolicyBlockLocator,
    PermissionsPolicyBlockReason,
    PermissionsPolicyFeature,
    PermissionsPolicyFeatureState,
    ProtocolHandler,
    ReferrerPolicy,
    RelatedApplication,
    ScopeExtension,
    ScreencastFrameMetadata,
    Screenshot,
    ScriptFontFamilies,
    ScriptIdentifier,
    SecureContextType,
    SecurityOriginDetails,
    ShareTarget,
    Shortcut,
    TransitionType,
    Viewport,
    VisualViewport,
    WebAppManifest,
)

__all__ = [
    FrameId,
    AdFrameType,
    AdFrameExplanation,
    AdFrameStatus,
    AdScriptId,
    AdScriptAncestry,
    SecureContextType,
    CrossOriginIsolatedContextType,
    GatedAPIFeatures,
    PermissionsPolicyFeature,
    PermissionsPolicyBlockReason,
    PermissionsPolicyBlockLocator,
    PermissionsPolicyFeatureState,
    OriginTrialTokenStatus,
    OriginTrialStatus,
    OriginTrialUsageRestriction,
    OriginTrialToken,
    OriginTrialTokenWithStatus,
    OriginTrial,
    SecurityOriginDetails,
    Frame,
    FrameResource,
    FrameResourceTree,
    FrameTree,
    ScriptIdentifier,
    TransitionType,
    NavigationEntry,
    ScreencastFrameMetadata,
    DialogType,
    AppManifestError,
    AppManifestParsedProperties,
    LayoutViewport,
    VisualViewport,
    Viewport,
    FontFamilies,
    ScriptFontFamilies,
    FontSizes,
    ClientNavigationReason,
    ClientNavigationDisposition,
    InstallabilityErrorArgument,
    InstallabilityError,
    ReferrerPolicy,
    CompilationCacheParams,
    FileFilter,
    FileHandler,
    ImageResource,
    LaunchHandler,
    ProtocolHandler,
    RelatedApplication,
    ScopeExtension,
    Screenshot,
    ShareTarget,
    Shortcut,
    WebAppManifest,
    NavigationType,
    BackForwardCacheNotRestoredReason,
    BackForwardCacheNotRestoredReasonType,
    BackForwardCacheBlockingDetails,
    BackForwardCacheNotRestoredExplanation,
    BackForwardCacheNotRestoredExplanationTree,
    DomContentEventFired,
    FileChooserOpened,
    FrameAttached,
    FrameClearedScheduledNavigation,
    FrameDetached,
    FrameSubtreeWillBeDetached,
    FrameNavigated,
    DocumentOpened,
    FrameResized,
    FrameStartedNavigating,
    FrameRequestedNavigation,
    FrameScheduledNavigation,
    FrameStartedLoading,
    FrameStoppedLoading,
    DownloadWillBegin,
    DownloadProgress,
    InterstitialHidden,
    InterstitialShown,
    JavascriptDialogClosed,
    JavascriptDialogOpening,
    LifecycleEvent,
    BackForwardCacheNotUsed,
    LoadEventFired,
    NavigatedWithinDocument,
    ScreencastFrame,
    ScreencastVisibilityChanged,
    WindowOpen,
    CompilationCacheProduced,
    AddScriptToEvaluateOnLoad,
    AddScriptToEvaluateOnNewDocument,
    BringToFront,
    CaptureScreenshot,
    CaptureSnapshot,
    ClearDeviceMetricsOverride,
    ClearDeviceOrientationOverride,
    ClearGeolocationOverride,
    CreateIsolatedWorld,
    DeleteCookie,
    Disable,
    Enable,
    GetAppManifest,
    GetInstallabilityErrors,
    GetManifestIcons,
    GetAppId,
    GetAdScriptAncestry,
    GetFrameTree,
    GetLayoutMetrics,
    GetNavigationHistory,
    ResetNavigationHistory,
    GetResourceContent,
    GetResourceTree,
    HandleJavaScriptDialog,
    Navigate,
    NavigateToHistoryEntry,
    PrintToPDF,
    Reload,
    RemoveScriptToEvaluateOnLoad,
    RemoveScriptToEvaluateOnNewDocument,
    ScreencastFrameAck,
    SearchInResource,
    SetAdBlockingEnabled,
    SetBypassCSP,
    GetPermissionsPolicyState,
    GetOriginTrials,
    SetDeviceMetricsOverride,
    SetDeviceOrientationOverride,
    SetFontFamilies,
    SetFontSizes,
    SetDocumentContent,
    SetDownloadBehavior,
    SetGeolocationOverride,
    SetLifecycleEventsEnabled,
    SetTouchEmulationEnabled,
    StartScreencast,
    StopLoading,
    Crash,
    Close,
    SetWebLifecycleState,
    StopScreencast,
    ProduceCompilationCache,
    AddCompilationCache,
    ClearCompilationCache,
    SetSPCTransactionMode,
    SetRPHRegistrationMode,
    GenerateTestReport,
    WaitForDebugger,
    SetInterceptFileChooserDialog,
    SetPrerenderingAllowed,
]
